@@ -31,7 +31,8 @@ class MyTextWrapper(textwrap.TextWrapper):
             r'(/|'                                    # a forward slash  
             r'\s+|'                                   # any whitespace
             r'[^\s\w]*\w+[^0-9\W]-(?=\w+[^0-9\W])|'   # hyphenated words
-            r'(?<=[\w\!\"\'\&\.\,\?])-{2,}(?=\w))')   # em-dash
+            r'(?<=[\w\!\"\'\&\.\,\?])-{2,}(?=\w))'    # em-dash
+            r'(?!&#8288;)')                           # UNLESS &wj;
 
         self.wordsep_re_uni = re.compile(self.wordsep_re.pattern, re.U)
 
@@ -43,17 +44,36 @@ class MyTextWrapper(textwrap.TextWrapper):
                              r'\Z'             # end of chunk
                              % string.lowercase)
 
-    def wrap(self, text, initial_indent='', subsequent_indent=''):
-        """ Wrapper method to dynamically change indentation strings """
-        self.initial_indent = initial_indent
-        self.subsequent_indent = subsequent_indent
-        return textwrap.TextWrapper.wrap(self, text)      
+    def replace(self, text):
+        """ Replace control entities with the proper character 
+            after breaking has occured.
+        """
+        for key, val in _post_break_replacements.items():
+            text = re.sub(re.escape(key), val, text)
+        return text
 
-    def fill(self, text, initial_indent='', subsequent_indent=''):
-        """ Wrapper method to dynamically change indentation strings """
+    def wrap(self, text, break_on_hyphens=True, initial_indent='', subsequent_indent=''):
+        """ Mirrored implementation of wrap which replaces characters properly
+            also lets you easily specify indentation on the fly
+        """
+        # Set indentation
         self.initial_indent = initial_indent
         self.subsequent_indent = subsequent_indent
-        return textwrap.TextWrapper.fill(self, text)
+        self.break_on_hyphens = break_on_hyphens
+
+        # Original implementation
+        text = self._munge_whitespace(text)
+
+        # Replace some characters after splitting has occured
+        chunks = map(self.replace, self._split(text))
+
+        # Original implementation
+        if self.fix_sentence_endings:
+            self._fix_sentence_endings(chunks)
+        return self._wrap_chunks(chunks)
+
+    def fill(self, *args, **kwargs):
+        return "\n".join(self.wrap(*args, **kwargs))
 
 
 def justify_inline(left_str, center_str, right_str, width=72):
@@ -102,6 +122,41 @@ def formatXmlWhitespace(tree):
                                element.tail))
 
 
+def int2roman(number, uppercase=False):
+    numerals = { 
+        1 : "i", 
+        4 : "iv", 
+        5 : "v", 
+        9 : "ix", 
+        10 : "x", 
+        40 : "xl", 
+        50 : "l", 
+        90 : "xc", 
+        100 : "c", 
+        400 : "cd", 
+        500 : "d", 
+        900 : "cm", 
+        1000 : "m" 
+    }
+    result = ""
+    for value, numeral in sorted(numerals.items(), reverse=True):
+        while number >= value:
+            result += numeral
+            number -= value
+    return uppercase and result.upper() or result
+
+
+def urlkeep(text):
+    """ Insert word join XML entities on forward slashes and hyphens
+        in a URL so that it stays on one line
+    """
+    wj_char = '&#8288;'
+    def replacer(match):
+        return match.group(0).replace('/', '/' + wj_char) \
+                             .replace('-', '-' + wj_char)
+    return re.sub('(?<=http:)\S*', replacer, text)
+
+
 def safeReplaceUnicode(tree):
     """ Traverses an lxml.etree ElementTree and replaces unicode characters 
         with the proper equivalents specified in rfc2629-xhtml.ent.
@@ -135,15 +190,14 @@ def _replace_unicode_characters(str):
         str = str.encode('ascii')
     except UnicodeEncodeError:
         str = str.encode('ascii', 'xmlcharrefreplace')
-        xml2rfc.log.warn('Unicode character(s) not replaced in string:\n  ' + \
-                         str)
+        # xml2rfc.log.warn('Unicode character(s) not replaced in string:\n  ' + \
+                         # str)
     return str
 
 
 # Ascii representations of unicode chars from rfc2629-xhtml.ent
 # Auto-generated from comments in rfc2629-xhtml.ent
 _unicode_replacements = {
-    '\xa0': ' ',
     '\xa1': '!',
     '\xa2': '[cents]',
     '\xa3': 'GBP',
@@ -309,6 +363,11 @@ _unicode_replacements = {
     u'\u017d': 'Z',
     u'\u017e': 'z',
     u'\u2010': '-',
-    u'\u2011': '-',
-    u'\u2060': '',
+}
+
+# XmlCharRef replacements that occur AFTER line breaking logic
+_post_break_replacements = {
+    '&#160;': ' ',   # nbsp
+    '&#8209;': '-',  # nbhy
+    '&#8288;': '',   # wj
 }
