@@ -9,6 +9,7 @@ import datetime
 import lxml
 import xml2rfc.log
 import xml2rfc.utils
+from xml2rfc.utils import urlkeep
 
 
 class _RfcItem:
@@ -98,7 +99,7 @@ class BaseRfcWriter:
     # Category names
     boilerplate['std'] = 'Standards Track'
     boilerplate['bcp'] = 'Best Current Practice'
-    boilerplate['exp'] = 'Experimental Protocol'
+    boilerplate['exp'] = 'Experimental'
     boilerplate['info'] = 'Informational'
     boilerplate['historic'] = 'Historic'
 
@@ -191,22 +192,22 @@ class BaseRfcWriter:
         '5741.'
 
     # Paragraph 3
-    boilerplate['status']['p3'] = \
-        'Information about the current status of this document, any errata, ' \
-        'and how to provide feedback on it may be obtained at ' \
-        'http://www.rfc-editor.org/info/rfc%s.'
+    boilerplate['status']['p3'] = urlkeep(''
+        'Information about the current status of this document, any errata, '
+        'and how to provide feedback on it may be obtained at '
+        'http://www.rfc-editor.org/info/rfc%s.')
 
     # 'Status of this Memo' boilerplate for drafts
-    boilerplate['status']['draft'] = \
-       ['Internet-Drafts are working documents of the Internet Engineering ' \
-       'Task Force (IETF).  Note that other groups may also distribute ' \
-       'working documents as Internet-Drafts.  The list of current Internet- ' \
+    boilerplate['status']['draft'] = map(urlkeep,
+       ['Internet-Drafts are working documents of the Internet Engineering '
+       'Task Force (IETF).  Note that other groups may also distribute '
+       'working documents as Internet-Drafts.  The list of current Internet- '
        'Drafts is at http://datatracker.ietf.org/drafts/current/.',
 
-       'Internet-Drafts are draft documents valid for a maximum of six months ' \
-       'and may be updated, replaced, or obsoleted by other documents at any ' \
-       'time.  It is inappropriate to use Internet-Drafts as reference ' \
-       'material or to cite them other than as "work in progress."']
+       'Internet-Drafts are draft documents valid for a maximum of six months '
+       'and may be updated, replaced, or obsoleted by other documents at any '
+       'time.  It is inappropriate to use Internet-Drafts as reference '
+       'material or to cite them other than as "work in progress."'])
     boilerplate['draft_expire'] = \
        'This Internet-Draft will expire on %s.'
 
@@ -222,13 +223,13 @@ class BaseRfcWriter:
     boilerplate['base_copyright_header'] = \
         'Copyright (c) %s IETF Trust and the persons identified as the ' \
         'document authors.  All rights reserved.'
-    boilerplate['base_copyright_body'] = \
-        'This document is subject to BCP 78 and the IETF Trust\'s Legal ' \
-        'Provisions Relating to IETF Documents ' \
-        '(http://trustee.ietf.org/license-info) in effect on the date of ' \
-        'publication of this document.  Please review these documents ' \
-        'carefully, as they describe your rights and restrictions with respect ' \
-        'to this document.'
+    boilerplate['base_copyright_body'] = urlkeep(''
+        'This document is subject to BCP 78 and the IETF Trust\'s Legal '
+        'Provisions Relating to IETF Documents '
+        '(http://trustee.ietf.org/license-info) in effect on the date of '
+        'publication of this document.  Please review these documents '
+        'carefully, as they describe your rights and restrictions with respect '
+        'to this document.')
 
     # IPR values which append things to copyright
     boilerplate['ipr_200902_copyright_ietfbody'] = \
@@ -429,6 +430,21 @@ class BaseRfcWriter:
                     # Warn about no date
                     xml2rfc.log.warn('No date specified for document.')
 
+    def _format_counter(self, text, count):
+        """ Return a proper string for a formatted list bullet.  Allowed types:
+                %c: Lowercase chars
+                %C: Uppercase chars
+                %d: Digits
+                %i: Lowercase roman numerals
+                %I: Uppercase roman numerals
+        """
+        return text \
+            .replace(r'%d', str(count)) \
+            .replace(r'%c', str(string.ascii_lowercase[(count - 1) % 26])) \
+            .replace(r'%C', str(string.ascii_uppercase[(count - 1) % 26])) \
+            .replace(r'%i', xml2rfc.utils.int2roman(count)) \
+            .replace(r'%I', xml2rfc.utils.int2roman(count, uppercase=True))
+
     def _prepare_top_left(self):
         """ Returns a lines of lines for the top left header """
         lines = []
@@ -540,83 +556,87 @@ class BaseRfcWriter:
     def _write_figure(self, figure):
         """ Writes <figure> elements """
         align = figure.attrib.get('align', self.defaults['figure_align'])
-        self.figure_count += 1
         anchor = figure.attrib.get('anchor')
         title = figure.attrib.get('title', self.defaults['figure_title'])
-    
-        if self.indexmode:
-            # Add figure to the index, inserting any anchors necessary
-            self._indexFigure(self.figure_count, anchor=anchor, title=title)
-        else:
+
+        # Keep track of count if there is an anchor, or PI was enabled
+        if anchor or self.pis.get('figurecount', 'no') == 'yes':
+            self.figure_count += 1
+        
+        if anchor:
             # Insert anchor(s) for the figure
             self.insert_anchor('#rfc.figure.' + str(self.figure_count))
-            if (anchor):
-                self.insert_anchor('#' + anchor)
-    
-            # Write preamble
-            preamble = figure.find('preamble')
-            if preamble is not None:
-                self.write_t_rec(preamble, align=align)
-    
-            # Write figure with optional delimiter
-            delimiter = self.pis.get('artworkdelimiter', None)
-            artwork = figure.find('artwork')
-            # artwork_align = artwork.attrib.get('align', align)
-            # Explicitly use figure alignment
-            artwork_align = align
-            blanklines = int(self.pis.get('artworklines', 0))
-            self.write_raw(figure.find('artwork').text, align=artwork_align, \
-                           blanklines=blanklines, delimiter=delimiter)
-    
-            # Write postamble
-            postamble = figure.find('postamble')
-            if postamble is not None:
-                self.write_t_rec(postamble, align=align)
-    
-            # Write label if PI figurecount = yes
-            if self.pis.get('figurecount', 'no') == 'yes':
-                title = figure.attrib.get('title', '')
-                if title:
-                    title = ': ' + title
-                self.write_label('Figure ' + str(self.figure_count) + title, \
-                                type='figure')
+            self.insert_anchor('#' + anchor)
+            if self.indexmode:
+                # Add figure to the index, inserting any anchors necessary
+                self._indexFigure(self.figure_count, anchor=anchor, title=title)
+
+        # Write preamble
+        preamble = figure.find('preamble')
+        if preamble is not None:
+            self.write_t_rec(preamble, align=align)
+
+        # Write figure with optional delimiter
+        delimiter = self.pis.get('artworkdelimiter', None)
+        artwork = figure.find('artwork')
+        # artwork_align = artwork.attrib.get('align', align)
+        # Explicitly use figure alignment
+        artwork_align = align
+        blanklines = int(self.pis.get('artworklines', 0))
+        self.write_raw(figure.find('artwork').text, align=artwork_align, \
+                       blanklines=blanklines, delimiter=delimiter)
+
+        # Write postamble
+        postamble = figure.find('postamble')
+        if postamble is not None:
+            self.write_t_rec(postamble, align=align)
+
+        # Write label if anchor is set or PI figurecount = yes
+        if anchor or self.pis.get('figurecount', 'no') == 'yes':
+            title = figure.attrib.get('title', '')
+            if title:
+                title = ': ' + title
+            self.write_label('Figure ' + str(self.figure_count) + title, \
+                            type='figure')
 
     def _write_table(self, table):
         """ Writes <texttable> elements """
         align = table.attrib.get('align', self.defaults['table_align'])
-        self.table_count += 1
         anchor = table.attrib.get('anchor')
         title = table.attrib.get('title', self.defaults['table_title'])
-        
-        if self.indexmode:
-            # Add table to the index, inserting any anchors necessary
-            self._indexTable(self.table_count, anchor=anchor, title=title)
-        else:
+
+        # Keep track of count if there is an anchor, or PI was enabled
+        if anchor or self.pis.get('tablecount', 'no') == 'yes':
+            self.table_count += 1
+
+        if anchor:
             # Insert anchor(s) for the table
             self.insert_anchor('#rfc.table.' + str(self.table_count))
-            if (anchor):
-                self.insert_anchor('#' + anchor)
-    
-            # Write preamble
-            preamble = table.find('preamble')
-            if preamble is not None:
-                self.write_t_rec(preamble, align=align)
-    
-            # Write table
-            self.draw_table(table, table_num=self.table_count)
-    
-            # Write postamble
-            postamble = table.find('postamble')
-            if postamble is not None:
-                self.write_t_rec(postamble, align=align)
-    
-            # Write label if PI tablecount = yes
-            if self.pis.get('tablecount', 'no') == 'yes':
-                title = table.attrib.get('title', '')
-                if title:
-                    title = ': ' + title
-                self.write_label('Table ' + str(self.table_count) + title, \
-                                 type='table')
+            self.insert_anchor('#' + anchor)
+            if self.indexmode:
+                # Add table to the index, inserting any anchors necessary
+                self._indexTable(self.table_count, anchor=anchor, title=title)
+
+        # Write preamble
+        preamble = table.find('preamble')
+        if preamble is not None:
+            self.write_t_rec(preamble, align=align)
+
+        # Write table
+        self.draw_table(table, table_num=self.table_count)
+
+        # Write postamble
+        postamble = table.find('postamble')
+        if postamble is not None:
+            self.write_t_rec(postamble, align=align)
+
+        # Write label if anchor is set or PI figurecount = yes
+        if anchor or self.pis.get('tablecount', 'no') == 'yes':
+            title = table.attrib.get('title', '')
+            if title:
+                title = ': ' + title
+            self.write_label('Table ' + str(self.table_count) + title, \
+                             type='table')
     
     def _index_t_rec(self, element):
         """ Traverse a <t> element only performing indexing operations """
@@ -696,14 +716,15 @@ class BaseRfcWriter:
     def _write_status_section(self):
         """ Writes the 'Status of this Memo' section """
 
-        self.write_heading('Status of this Memo', autoAnchor='rfc.status')
+        self.write_heading('Status of This Memo', autoAnchor='rfc.status')
         if not self.draft:  #RFC
             # Status boilerplate is determined by category/submissionType/consensus
             category = self.r.attrib.get('category', 'none')
             stream = self.r.attrib.get('submissionType', 
                                        self.defaults['submissionType'])
-            consensus = self.r.attrib.get('consensus',
-                                          self.defaults['consensus'])
+            # Consensus is assumed 'yes' for Standards Track documents
+            consensus = category == 'std' and 'yes' or \
+                        self.r.attrib.get('consensus', self.defaults['consensus'])
             workgroup = ''
             wg_element = self.r.find('front/workgroup')
             if wg_element is not None and wg_element.text:
