@@ -75,9 +75,11 @@ class HtmlRfcWriter(BaseRfcWriter):
                 self.write_t_rec(t, parent=dd)
         elif style.startswith('format'):
             format_str = style.partition('format ')[2]
-            if not ('%c' in format_str or '%d' in format_str):
-                xml2rfc.log.warn('No %c or %d found in list format '\
-                                 'string: ' + style)
+            allowed_formats = ('%c', '%C', '%d', '%i', '%I')
+            if not any(map(lambda format: format in format_str, allowed_formats)):
+                xml2rfc.log.warn('Invalid format specified: %s ' 
+                                 '(Must be one of %s)' % (style,
+                                    ', '.join(allowed_formats)))
             counter_index = list.attrib.get('counter', None)
             if not counter_index:
                 counter_index = 'temp'
@@ -89,13 +91,7 @@ class HtmlRfcWriter(BaseRfcWriter):
             for t in list.findall('t'):
                 self.list_counters[counter_index] += 1
                 count = self.list_counters[counter_index]
-                if '%d' in format_str:
-                    bullet = format_str.replace(r'%d', str(count) + ' ')
-                elif '%c' in format_str:
-                    bullet = format_str.replace(r'%c', \
-                                str(string.ascii_lowercase[count % 26]) + ' ')
-                else:
-                    bullet = format_str
+                bullet = self._format_counter(format_str, count) + ' '
                 dt = E.DT(bullet)
                 dd = E.DD()
                 list_elem.append(dt)
@@ -369,6 +365,7 @@ class HtmlRfcWriter(BaseRfcWriter):
         subs['fullname'] = author.attrib.get('fullname', '')
         subs['surname'] = author.attrib.get('surname', '')
         subs['role'] = author.attrib.get('role', '')
+        subs['role'] = subs['role'] and "(%s)" % subs['role'] or ''
         subs['organization'] = author.find('organization') is not None and \
                                author.find('organization').text or ''
         address = author.find('address')
@@ -405,9 +402,9 @@ class HtmlRfcWriter(BaseRfcWriter):
                 span = E.SPAN('Phone: ' + phone.text)
                 span.attrib['class'] = 'vcardline'
                 contact_div.append(span)
-            fascimile = address.find('fascimile')
-            if fascimile is not None and fascimile.text:
-                span = E.SPAN('Fax: ' + fascimile.text)
+            facsimile = address.find('facsimile')
+            if facsimile is not None and facsimile.text:
+                span = E.SPAN('Fax: ' + facsimile.text)
                 span.attrib['class'] = 'vcardline'
                 contact_div.append(span)
             email = address.find('email')
@@ -617,6 +614,7 @@ class HtmlRfcWriter(BaseRfcWriter):
                         'header_rows': [],
                         'toc_head_links': [],
                         'toc_rows': []}
+        self.list_counters = {}
         self.active_buffer = self.buffers['front']
 
     def post_processing(self):
