@@ -122,9 +122,11 @@ class RawTextRfcWriter(BaseRfcWriter):
         counter_index = None
         if style.startswith('format'):
             format_str = style.partition('format ')[2]
-            if not ('%c' in format_str or '%d' in format_str):
-                xml2rfc.log.warn('No %c or %d found in list format '\
-                                 'string: ' + style)
+            allowed_formats = ('%c', '%C', '%d', '%i', '%I')
+            if not any(map(lambda format: format in format_str, allowed_formats)):
+                xml2rfc.log.warn('Invalid format specified: %s ' 
+                                 '(Must be one of %s)' % (style,
+                                    ', '.join(allowed_formats)))
             counter_index = list.attrib.get('counter', None)
             if not counter_index:
                 counter_index = 'temp'
@@ -166,13 +168,7 @@ class RawTextRfcWriter(BaseRfcWriter):
                 elif style.startswith('format'):
                     self.list_counters[counter_index] += 1
                     count = self.list_counters[counter_index]
-                    if '%d' in format_str:
-                        bullet = format_str.replace(r'%d', str(count) + ' ')
-                    elif '%c' in format_str:
-                        bullet = format_str.replace(r'%c', \
-                                str(string.ascii_lowercase[count % 26]) + ' ')
-                    else:
-                        bullet = format_str
+                    bullet = self._format_counter(format_str, count) + ' '
                 self.write_t_rec(element, bullet=bullet, indent=indent, \
                                  level=level + 1, \
                                  sub_indent=hangIndent, lb=lb)
@@ -480,11 +476,13 @@ class RawTextRfcWriter(BaseRfcWriter):
                     self._write_list(element, indent=new_indent, level=level)
                     # Auto-break for tail paragraph
                     lb = True
+                    bullet = ''
 
                 elif element.tag == 'figure':
                     self._write_figure(element)
                     # Auto-break for tail paragraph
                     lb = True
+                    bullet = ''
 
                 elif element.tag == 'vspace':
                     # Insert `blankLines` blank lines into document
@@ -492,9 +490,8 @@ class RawTextRfcWriter(BaseRfcWriter):
                                          self.defaults['vspace_blanklines'])))
                     # Don't auto-break for tail paragraph
                     lb = False
-
-                # Dont use a bullet for any other paragraphs at this level
-                bullet = ''
+                    # Keep indentation
+                    bullet = ' ' * len(bullet)
 
                 # Set tail of element as input text of next paragraph
                 if element.tail:
@@ -525,8 +522,8 @@ class RawTextRfcWriter(BaseRfcWriter):
         """ Writes a simple address card with no line breaks """
         lines = []
         if 'role' in author.attrib:
-                lines.append(author.attrib.get('fullname', '') + ', ' + \
-                             author.attrib['role'])
+            lines.append("%s (%s)" % (author.attrib.get('fullname', ''),
+                                      author.attrib.get('role', '')))
         else:
             lines.append(author.attrib.get('fullname', ''))
         organization = author.find('organization')
@@ -560,9 +557,9 @@ class RawTextRfcWriter(BaseRfcWriter):
             phone = address.find('phone')
             if phone is not None and phone.text:
                 lines.append('Phone: ' + phone.text)
-            fascimile = address.find('fascimile')
-            if fascimile is not None and fascimile.text:
-                lines.append('Fax:   ' + fascimile.text)
+            facsimile = address.find('facsimile')
+            if facsimile is not None and facsimile.text:
+                lines.append('Fax:   ' + facsimile.text)
             email = address.find('email')
             if email is not None and email.text:
                 label = self.pis.get('rfcedstyle', 'no') == 'yes' and 'EMail' or 'Email'
@@ -831,6 +828,7 @@ class RawTextRfcWriter(BaseRfcWriter):
         self.buf = []
         
         # Reset document counters from indexing pass
+        self.list_counters = {}
         self.edit_counter = 0   # Counter for edit marks
         self.eref_counter = 0   # Counter for <eref> elements
 
